@@ -1,7 +1,7 @@
 import pytest
 from datetime import datetime
 
-from marshmallow import fields, INCLUDE, RAISE, Schema, validate
+from marshmallow import EXCLUDE, fields, INCLUDE, RAISE, Schema, validate
 
 from apispec.ext.marshmallow import MarshmallowPlugin
 from apispec import exceptions, utils, APISpec
@@ -152,6 +152,16 @@ class TestMarshmallowSchemaToModelDefinition:
         res = openapi.schema2jsonschema(UnknownIncludeSchema)
         assert res["additionalProperties"] is True
 
+    def test_unknown_values_ignore(self, openapi):
+        class UnknownExcludeSchema(Schema):
+            class Meta:
+                unknown = EXCLUDE
+
+            first = fields.Str()
+
+        res = openapi.schema2jsonschema(UnknownExcludeSchema)
+        assert "additionalProperties" not in res
+
     def test_only_explicitly_declared_fields_are_translated(self, openapi):
         class UserSchema(Schema):
             _id = fields.Int()
@@ -189,8 +199,10 @@ class TestMarshmallowSchemaToModelDefinition:
         class NotASchema:
             pass
 
-        expected_error = "{!r} doesn't have either `fields` or `_declared_fields`.".format(
-            NotASchema
+        expected_error = (
+            "{!r} doesn't have either `fields` or `_declared_fields`.".format(
+                NotASchema
+            )
         )
         with pytest.raises(ValueError, match=expected_error):
             openapi.schema2jsonschema(NotASchema)
@@ -308,8 +320,8 @@ class TestMarshmallowSchemaToParameters:
         class NotASchema:
             pass
 
-        expected_error = "{!r} doesn't have either `fields` or `_declared_fields`".format(
-            NotASchema
+        expected_error = (
+            f"{NotASchema!r} doesn't have either `fields` or `_declared_fields`"
         )
         with pytest.raises(ValueError, match=expected_error):
             openapi.schema2jsonschema(NotASchema)
@@ -416,7 +428,8 @@ def test_openapi_tools_validate_v2():
                     },
                     openapi._field2parameter(
                         field=fields.List(
-                            fields.Str(), validate=validate.OneOf(["freddie", "roger"]),
+                            fields.Str(),
+                            validate=validate.OneOf(["freddie", "roger"]),
                         ),
                         location="query",
                         name="body",
@@ -472,7 +485,8 @@ def test_openapi_tools_validate_v3():
                     },
                     openapi._field2parameter(
                         field=fields.List(
-                            fields.Str(), validate=validate.OneOf(["freddie", "roger"]),
+                            fields.Str(),
+                            validate=validate.OneOf(["freddie", "roger"]),
                         ),
                         location="query",
                         name="body",
@@ -545,7 +559,11 @@ class TestFieldValidation:
         equal_length = fields.Str(
             validate=[validate.Length(equal=5), validate.Length(min=1, max=10)]
         )
-        date_range = fields.DateTime(validate=validate.Range(min=datetime(1900, 1, 1),))
+        date_range = fields.DateTime(
+            validate=validate.Range(
+                min=datetime(1900, 1, 1),
+            )
+        )
 
     @pytest.mark.parametrize(
         ("field", "properties"),
